# include <QtGui>

# include "ipsecstatus.h"
# include "settings.h"

ipsecstatus::ipsecstatus(QWidget *parent): QDialog(parent)
{
	setupUi(this);

	QApplication::setQuitOnLastWindowClosed(false);
	QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));

	settings=0;   // Der settings-Dialog
	conn_state=0; // conn_state: 0=Disconnected, 1=Connected

	QTimer::singleShot(0, this, SLOT(check_sound_system()));

	// Icons für Systray festlegen
	verzeichnis=QCoreApplication::applicationDirPath();
	key_disconnected= verzeichnis+"/key_disconnected_32x32.png";
	key_connected = verzeichnis+"/key_connected_32x32.png";
	ani_connecting << verzeichnis+"/animation/connecting_32x32_01.png" << verzeichnis+"/animation/connecting_32x32_02.png" << verzeichnis+"/animation/connecting_32x32_03.png" << verzeichnis+"/animation/connecting_32x32_04.png" << verzeichnis+"/animation/connecting_32x32_05.png" << verzeichnis+"/animation/connecting_32x32_06.png";
	ani_i=0;

	// Actions für das systray-Menü festlegen
	createActions();
	createTrayIcon();
	trayIcon->show();


	connect(minimizeButton, SIGNAL(clicked()), this, SLOT(hideDialog()));
	connect(&proc, SIGNAL(readyReadStandardOutput()), this, SLOT(status_result()));
	connect(&proc, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(start_timer()));
	connect(trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), this, SLOT(iconActivated(QSystemTrayIcon::ActivationReason)));

	timer = new QTimer(this);
	connect(timer,SIGNAL(timeout()),this,SLOT(get_status()));
	start_timer();


	/************************************************
	conf-Datei mit den Einstellungen laden
	************************************************/

	int zeilen=0;
	int i;
	QString line;
	QString check_Path_conn;
	QString check_Path_disconn;
	QStringList daten;
	QString verzeichnis=QCoreApplication::applicationDirPath();
	verzeichnis.append("/settings.conf");

	QFile datei(verzeichnis);
	if (datei.open(QIODevice::ReadOnly | QIODevice::Text))
		{
		QApplication::setOverrideCursor(Qt::WaitCursor);
	
		QTextStream in(&datei);
		while(!in.atEnd())
			{
			line = in.readLine();
			daten << line;
			zeilen++;
			}
		}
	datei.close();

	if(!daten.isEmpty())
		{
		for(i=0;i<zeilen;i++)
			{
			if(daten[i].contains("# Audio"))
				{
				check_Path_conn=daten[i+1].remove("Connected: ");
				check_Path_disconn=daten[i+2].remove("Disconnected: ");
				}
			}
		}
	QApplication::restoreOverrideCursor();

	if(!check_Path_conn.isEmpty())
		AudioMessageConn=check_Path_conn;
	if(!check_Path_disconn.isEmpty())
		AudioMessageDisconn=check_Path_disconn;


}

// ---------------------- END OF MAIN FUNKTION --------------------------------



/**************************************************************
      Der minimize-Button schließt lediglich das Fenster
 ***************************************************************/
void ipsecstatus::hideDialog()
{
    if (trayIcon->isVisible())
	{
        hide();
	}
}


/**************************************************************
      Timer starten
 ***************************************************************/
void ipsecstatus::start_timer()
{
	timerwert=1000;
	timer->start(timerwert);
}


/**************************************************************
      Die IPsec Status abfrage mittels # ipsec status
 ***************************************************************/
void ipsecstatus::get_status()
{
	QStringList args;
	args << "status";
	proc.start("ipsec", args);
}

/**************************************************************
      Die Konsolen-Ausgabe von ipsec status
 ***************************************************************/
void ipsecstatus::status_result()
{
	QByteArray data= proc.readAllStandardOutput();
	stdausgabe= QString::fromLocal8Bit(data);

	QRegExp hosts_up("[1-9] up");
	if(stdausgabe.contains(hosts_up) && stdausgabe.contains("CONNECTING"))
		{
		if(ani_i==6)
			ani_i=0;
		QString current_ani = ani_connecting[ani_i];
		QIcon icon = QIcon(current_ani);
		trayIcon->setIcon(icon);
		setWindowIcon(icon);
		ani_i++;
		}
	else if(stdausgabe.contains(hosts_up) && stdausgabe.contains("DELETING"))
		{
		if(ani_i==6)
			ani_i=0;
		QString current_ani = ani_connecting[ani_i];
		QIcon icon = QIcon(current_ani);
		trayIcon->setIcon(icon);
		setWindowIcon(icon);
		ani_i++;
		}	
	else if(stdausgabe.contains(hosts_up) && stdausgabe.contains("ESTABLISHED") && stdausgabe.contains("INSTALLED"))
		{
		QIcon icon = QIcon(key_connected);
		trayIcon->setIcon(icon);
		setWindowIcon(icon);

		if(conn_state!=1)
			{
			// Audio-Datei AudioMessageConn abspielen
			QStringList args_play_conn;
			args_play_conn << AudioMessageConn;

			QFileInfo test1("/usr/bin/play");
			QFileInfo test2("/usr/bin/mplayer");
			if(test1.exists())
				play_audio_conn.start("play", args_play_conn);
			else if(test2.exists())
				play_audio_conn.start("mplayer", args_play_conn);

			conn_state=1;
			}
		}
	else if(stdausgabe.contains("0 up") && stdausgabe.contains("none"))
		{
		QIcon icon = QIcon(key_disconnected);
		trayIcon->setIcon(icon);
		setWindowIcon(icon);

		if(conn_state!=0)
			{
			// Audio-Datei AudioMessageDisconn abspielen
			QStringList args_play_disconn;
			args_play_disconn << AudioMessageDisconn;

			QFileInfo test1("/usr/bin/play");
			QFileInfo test2("/usr/bin/mplayer");
			if(test1.exists())
				play_audio_disconn.start("play", args_play_disconn);
			else if(test2.exists())
				play_audio_disconn.start("mplayer", args_play_disconn);

			conn_state=0;
			}
		}

	QString timestamp = QDateTime::currentDateTime().toString("dddd, dd.MM.yyyy hh:mm:ss");
	QString log_ausgabe=timestamp+"\n"+"\n"+stdausgabe;
	IPsec_textEdit->setText(log_ausgabe);
}


/**************************************************************
   Das Schließen des Fensters per close-Button oder X
   abfangen und nur im Systray verkleinern (Window hide)
 ***************************************************************/

void ipsecstatus::closeEvent(QCloseEvent *event)
{
    if (trayIcon->isVisible())
	{
        QMessageBox::information(this, tr("Systray"),
                                 tr("ipsec-status will keep running in the "
                                    "system tray.<br>To terminate the program, "
                                    "choose <b>Quit</b> in the<br>context menu "
                                    "of the system tray entry."));
        hide();
        event->ignore();
	}
}


/**************************************************************
      Aktionen für das Systray-Icon
 ***************************************************************/
void ipsecstatus::createActions()
{
	minimizeAction = new QAction(tr("Mi&nimize"), this);
	connect(minimizeAction, SIGNAL(triggered()), this, SLOT(hide()));

	QFont font;
	font.setBold(true);
	restoreAction = new QAction(this);
	restoreAction->setText(tr("show &Window"));
	restoreAction->setFont(font);
	connect(restoreAction, SIGNAL(triggered()), this, SLOT(showNormal()));

	settingsAction = new QAction(tr("&Settings"), this);
	connect(settingsAction, SIGNAL(triggered()), this, SLOT(OpenSettingsDialog()));

	quitAction = new QAction(tr("&Quit"), this);
	connect(quitAction, SIGNAL(triggered()), qApp, SLOT(quit()));
}


/**************************************************************
     Das Systray-Icon erzeugen
 ***************************************************************/
void ipsecstatus::createTrayIcon()
{
	trayIcon = new QSystemTrayIcon(this);
	QIcon icon = QIcon(key_disconnected);
	trayIcon->setIcon(icon);
	setWindowIcon(icon);

	trayIconMenu = new QMenu(this);
	trayIconMenu->addAction(minimizeAction);
	trayIconMenu->addAction(restoreAction);
	trayIconMenu->addAction(settingsAction);
	trayIconMenu->addSeparator();
	trayIconMenu->addAction(quitAction);

	trayIcon->setContextMenu(trayIconMenu);
}


/**************************************************************
     Wenn das Systray-Icon geklickt wird
 ***************************************************************/

void ipsecstatus::iconActivated(QSystemTrayIcon::ActivationReason reason)
{
	if(reason==QSystemTrayIcon::Trigger)
		{
		show();
		raise();
		activateWindow();
		}
}


/**************************************************************
     Einstellungs-Dialog für Audio
 ***************************************************************/

void ipsecstatus::OpenSettingsDialog()
{
	if(settings)
		{
		delete settings;
		}
	settings = new settingsDialog(this);
	connect(settings, SIGNAL(retAudioPath(const QString &,const QString &)), this, SLOT(selectedAudio(const QString &,const QString &)));
	settings->show();
	settings->raise();
	settings->activateWindow();
}


/****************************************************************
 * Audio Pfad Auswahl übernehmen                                *
 ***************************************************************/

void ipsecstatus::selectedAudio(const QString &selectedPathconn,const QString &selectedPathdisconn)
{
	AudioMessageConn = selectedPathconn;
	AudioMessageDisconn = selectedPathdisconn;
}


/****************************************************************
 * Check auf installiertes Soundsystem, entweder sox oder alsa  *
 ***************************************************************/

void ipsecstatus::check_sound_system()
{
	QFileInfo test1("/usr/bin/play");
	QFileInfo test2("/usr/bin/mplayer");
	if(!test1.exists() && !test2.exists())
		{
		font.setPointSize(12);
		QMessageBox msgBox;
		msgBox.setStandardButtons(QMessageBox::Ok);
		msgBox.setFont(font);
		msgBox.setIcon(QMessageBox::Critical);
		msgBox.setWindowTitle("ipsec-status: Error");
		msgBox.setText(tr("<b>Fehler: Weder sox noch mplayer gefunden.</b><br><br>"
			"Soundausgabe nicht verfügbar.<br>"
			"Installieren sie entweder das Paket<br>"
			"<b>sox</b> oder <b>mplayer</b>."));
		msgBox.exec();
		}
}

