# include <QtGui>

# include "settings.h"

settingsDialog::settingsDialog(QWidget *parent): QDialog(parent)
{
	setupUi(this);

	connect(SaveButton, SIGNAL(clicked()), this, SLOT(saveSettings()));
	connect(CancelButton, SIGNAL(clicked()), this, SLOT(cancelSettings()));

	connect(ConnectedpushButton, SIGNAL(clicked()), this, SLOT(openConnected()));
	connect(DisconnectedpushButton, SIGNAL(clicked()), this, SLOT(openDisconnected()));

	connect(ConnPlayButton, SIGNAL(clicked()), this, SLOT(playConnected()));
	connect(DisconnPlayButton, SIGNAL(clicked()), this, SLOT(playDisconnected()));


	/************************************************
	conf-Datei mit den Einstellungen laden
	************************************************/

	int zeilen=0;
	int i;
	QString line;
	QStringList daten;
	QString verzeichnis=QCoreApplication::applicationDirPath();
	verzeichnis.append("/settings.conf");

	QFile datei(verzeichnis);
	if (datei.open(QIODevice::ReadOnly | QIODevice::Text))
		{
		QApplication::setOverrideCursor(Qt::WaitCursor);
	
		QTextStream in(&datei);
		while(!in.atEnd())
			{
			line = in.readLine();
			daten << line;
			zeilen++;
			}
		}
	datei.close();

	if(!daten.isEmpty())
		{
		for(i=0;i<zeilen;i++)
			{
			if(daten[i].contains("# Audio"))
				{
				ConnectedlineEdit->setText(daten[i+1].remove("Connected: "));
				DisconnectedlineEdit->setText(daten[i+2].remove("Disconnected: "));
				}
			}
		}
	QApplication::restoreOverrideCursor();

}



void settingsDialog::openConnected()
{
	QString initialDir = ConnectedlineEdit->text();
	if(initialDir.isEmpty())
		initialDir = "/usr/share/sounds/";

	QString InpFile = QFileDialog::getOpenFileName(this, "Open File Dialog", initialDir, "All Files(*.*)");

	if(!InpFile.isEmpty())
		ConnectedlineEdit->setText(InpFile);
}

void settingsDialog::openDisconnected()
{
	QString initialDir = DisconnectedlineEdit->text();
	if(initialDir.isEmpty())
		initialDir = "/usr/share/sounds/";

	QString InpFile = QFileDialog::getOpenFileName(this, "Open File Dialog", initialDir, "All Files(*.*)");

	if(!InpFile.isEmpty())
		DisconnectedlineEdit->setText(InpFile);
}


void settingsDialog::playConnected()
{
	// Audio-Datei AudioMessageConn abspielen
	QString soundfile = ConnectedlineEdit->text();
	QStringList args_testplay;
	args_testplay << soundfile;
	QFileInfo test1("/usr/bin/play");
	QFileInfo test2("/usr/bin/mplayer");
	if(test1.exists())
	play_audio_file.start("play", args_testplay);
	else if(test2.exists())
	play_audio_file.start("mplayer", args_testplay);

}


void settingsDialog::playDisconnected()
{
	// Audio-Datei AudioMessageConn abspielen
	QString soundfile = DisconnectedlineEdit->text();
	QStringList args_testplay;
	args_testplay << soundfile;
	QFileInfo test1("/usr/bin/play");
	QFileInfo test2("/usr/bin/mplayer");
	if(test1.exists())
	play_audio_file.start("play", args_testplay);
	else if(test2.exists())
	play_audio_file.start("mplayer", args_testplay);
}


void settingsDialog::saveSettings()
{
	QString verzeichnis=QCoreApplication::applicationDirPath();
	verzeichnis.append("/settings.conf");

	QFile datei(verzeichnis);
	if(datei.open(QFile::WriteOnly | QFile::Truncate))
		{
		QTextStream out(&datei);
		QApplication::setOverrideCursor(Qt::WaitCursor);

		out << endl;
		out << "# Audio" << endl;
		out << "Connected: " << ConnectedlineEdit->text() << endl;
		out << "Disconnected: " << DisconnectedlineEdit->text() << endl;
		out << endl;
		}

	QApplication::restoreOverrideCursor();
	datei.close();

	QString connectAudioPath = ConnectedlineEdit->text();
	QString disconnectAudioPath = DisconnectedlineEdit->text();
	emit retAudioPath(connectAudioPath, disconnectAudioPath);

	close();
}

void settingsDialog::cancelSettings()
{
	close();
}

